summaryrefslogtreecommitdiffstats
path: root/chrome/browser/web_applications/web_app.h
diff options
context:
space:
mode:
authorxiyuan@chromium.org <xiyuan@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-01-06 18:11:15 +0000
committerxiyuan@chromium.org <xiyuan@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-01-06 18:11:15 +0000
commit12f520c53db26ec0dc45f263904d8995e809e800 (patch)
treedefcb2b679cc43a1d0ebb85adcda4f606549883d /chrome/browser/web_applications/web_app.h
parenta1ca40db95ac3c0dc8c12c42fe736c800d46c00b (diff)
downloadchromium_src-12f520c53db26ec0dc45f263904d8995e809e800.zip
chromium_src-12f520c53db26ec0dc45f263904d8995e809e800.tar.gz
chromium_src-12f520c53db26ec0dc45f263904d8995e809e800.tar.bz2
Append profile info to win7 app id per issue 30414
Add profile info to app id for non-default profile so that win7 could group chrome icons based on profile. - Add a new chrome/common/win_util.h/cc to hold app id functions that would include profile info for non-default profiles; - Add unit test to the new GetChromiumAppId function; - Browser and JumpList to use the GetChromiumAppId for BrowserWindow and JumpList; - UserDataManager to use it for shortcuts it creates; - Make app id for web apps include profile info as well; - Change web_app::UpdateShortcuts to just update shortcuts description, icon and app id; BUG=30414 TEST=Verify fix for issue 30414. Review URL: http://codereview.chromium.org/506079 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@35634 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/web_applications/web_app.h')
-rw-r--r--chrome/browser/web_applications/web_app.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/chrome/browser/web_applications/web_app.h b/chrome/browser/web_applications/web_app.h
index 28b1e9c..56f26b6 100644
--- a/chrome/browser/web_applications/web_app.h
+++ b/chrome/browser/web_applications/web_app.h
@@ -25,20 +25,20 @@ std::wstring GenerateApplicationNameFromURL(const GURL& url);
typedef Callback1<bool>::Type CreateShortcutCallback;
// Creates a shortcut for web application based on given shortcut data.
// |root_dir| is used as root directory for persisted data such as icon.
// Directory layout is similar to what Gears has, i.e. an web application's
// file is stored under "#/host_name/scheme_port", where '#' is the
// |root_dir|.
void CreateShortcut(
- const FilePath& data_dir,
+ const FilePath& profile_path,
const ShellIntegration::ShortcutInfo& shortcut_info,
CreateShortcutCallback* callback);
// Returns true if given url is a valid web app url.
bool IsValidUrl(const GURL& url);
-// Returns data dir for web apps for given profile.
-FilePath GetDataDir(Profile* profile);
+// Returns data dir for web apps for given profile path.
+FilePath GetDataDir(const FilePath& profile_path);
// Extracts icons info from web app data. Take only square shaped icons and
// sort them from smallest to largest.
@@ -25,20 +25,20 @@ std::wstring GenerateApplicationNameFromURL(const GURL& url);
typedef Callback1<bool>::Type CreateShortcutCallback;
// Creates a shortcut for web application based on given shortcut data.
-// |root_dir| is used as root directory for persisted data such as icon.
+// |profile_path| is used as root directory for persisted data such as icon.
// Directory layout is similar to what Gears has, i.e. an web application's
// file is stored under "#/host_name/scheme_port", where '#' is the